# Remove-Item C:\Users\ADMINISTRATOR\Documents\DBReport.htm 
# New-Item -ItemType file -Path C:\Users\ADMINISTRATOR\Documents -Name dbreport.htm 

Add-PSSnapin Microsoft.Exchange.Management.PowerShell.E2010
Set-ExecutionPolicy -ExecutionPolicy RemoteSigned

$fileName = "C:\JournalDBReport.htm"
$serverlist = "C:\JournalServer.txt"
Clear-Content $Filename

$mailboxCountThreshold =  4
$dbSizeThreshold = 200GB
$backupThreshold = 7
$mbxSizeThreshold = 200GB
$itemcountwarning = 200000
$itemcountcritical = 300000

Function writeHtmlHeader 
{ 
param($fileName) 
$date = ( Get-Date ).ToString('yyyy/MM/dd - hh:mm') 
Add-Content $fileName "<html>" 
Add-Content $fileName "<head>" 
Add-Content $fileName "<meta http-equiv='Content-Type' content='text/html; charset=iso-8859-1'>" 
Add-Content $fileName '<title>Contoso Exchange Journal Report</title>' 
Add-Content $fileName '<STYLE TYPE="text/css">' 
Add-Content $fileName  "<!--" 
Add-Content $fileName  "td {" 
Add-Content $fileName  "font-family: Tahoma;" 
Add-Content $fileName  "font-size: 11px;" 
Add-Content $fileName  "border-top: 1px solid #999999;" 
Add-Content $fileName  "border-right: 1px solid #999999;" 
Add-Content $fileName  "border-bottom: 1px solid #999999;" 
Add-Content $fileName  "border-left: 1px solid #999999;" 
Add-Content $fileName  "padding-top: 0px;" 
Add-Content $fileName  "padding-right: 0px;" 
Add-Content $fileName  "padding-bottom: 0px;" 
Add-Content $fileName  "padding-left: 0px;" 
Add-Content $fileName  "}" 
Add-Content $fileName  "body {" 
Add-Content $fileName  "margin-left: 5px;" 
Add-Content $fileName  "margin-top: 5px;" 
Add-Content $fileName  "margin-right: 0px;" 
Add-Content $fileName  "margin-bottom: 10px;" 
Add-Content $fileName  "" 
Add-Content $fileName  "table {" 
Add-Content $fileName  "border: thin solid #000000;" 
Add-Content $fileName  "}" 
Add-Content $fileName  "-->" 
Add-Content $fileName  "</style>" 
Add-Content $fileName "</head>" 
Add-Content $fileName "<body>" 
Add-Content $fileName  "<table width='100%'>" 
Add-Content $fileName  "<tr bgcolor='#CCCCCC'>" 
Add-Content $fileName  "<td colspan='10' height='25' align='center'>" 
Add-Content $fileName  "<font face='tahoma' color='#003399' size='4'><strong>Contoso Exchange Journal Report - $date</strong></font>" 
Add-Content $fileName  "</td>" 
Add-Content $fileName  "</tr>" 
Add-Content $fileName  "</table>" 
} 
# Function to write the HTML Header to the file 
Function writeTableHeader 
{ 
param($fileName) 
Add-Content $fileName "<table width='100%'><tbody>"  
Add-Content $fileName "<tr bgcolor=#CCCCCC>" 
Add-Content $fileName "<td width='10%' align='center'>Database Name</td>" 
Add-Content $fileName "<td width='10%' align='center'>Server</td>" 
Add-Content $fileName "<td width='10%' align='center'>Top Mailbox</td>" 
Add-Content $fileName "<td width='10%' align='center'>Top Mailbox Size(MB)</td>" 
Add-Content $fileName "<td width='28%' align='center'>Number Of Items</td>"
Add-Content $fileName "<td width='15%' align='center'>Database File</td>" 
Add-Content $fileName "<td width='10%' align='center'>Database Size(MB)</td>" 

Add-Content $fileName "<td width='7%' align='center'># of Mailboxes</td>" 
Add-Content $fileName "<td width='10%' align='center'>WhiteSpace(MB)</td>" 
Add-Content $fileName "<td width='0%' align='center'>Oldest Item</td>"
Add-Content $fileName "<td width='0%' align='center'>Newest Item</td>" 
Add-Content $fileName "</tr>" 
} 
 
Function writeHtmlFooter 
{ 
param($fileName) 
Add-Content $fileName "</table>" 
Add-Content $fileName "</body>" 
Add-Content $fileName "</html>" 
} 
 
Function get-DBInfo 
{ 
 foreach ($server in $serverlist)
 {
 	$dbs = Get-MailboxDatabase -Status -Server $server
	 foreach($db in $dbs) 
	 { 
	    $name = $db.name 
	    $svr = $db.servername     
	    $edb = $db.edbfilepath     
	    $stats = Get-Mailbox -Database $db | Get-MailboxStatistics
	    $edbSize = $db.DatabaseSize.Tobytes() 
	    $whiteSpace = $db.AvailableNewMailboxSpace.Tobytes()/1mb 
	    $mbxCount = Get-Mailbox -Database $db | Measure-Object | Select-Object Count
	    $mbxCount = $mbxcount.count
	    $topMailbox = $stats | Sort-Object TotalItemSize -Descending |Select-Object DisplayName -First 1 | Format-Table Displayname -HideTableHeaders | Out-String 
	    $topMailboxSize = $stats | Sort-Object TotalItemSize -Descending | Select-Object totalitemsize -First 1 
	    $topMailboxSize = $topMailboxSize.TotalItemSize.Value.ToBytes()
	    $lastbackup = Get-Mailbox -Database $db | Get-MailboxFolderStatistics -IncludeOldestAndNewestItems -FolderScope "Inbox" | fl -Property OldestItemReceivedDate | Out-String
	    $howOldBkp = Get-Mailbox -Database $db | Get-MailboxFolderStatistics -IncludeOldestAndNewestItems -FolderScope "Inbox" | fl -Property NewestItemReceivedDate | Out-String
	    $ItemCounts = $stats | Select-Object -Property ItemCount -ExpandProperty ItemCount
	    $CountItems = $stats | Sort-Object ItemCount -Descending | Select-Object ItemCount -First 1
	    $CountItems = $CountItems.ItemCount
	    writedata $name $svr $edb $edbSize $whiteSpace $mbxCount $topMailbox $topMailboxSize $lastBackup $howOldBkp $CountItems $itemcounts
	} 
 }
  
} 
 
Function WriteData 
{ 
param($name,$svr,$edb,$edbSize,$whiteSpace,$mbxCount,$topMailbox,$topMailboxSize,$lastBackup,$howOldBkp,$CountItems,$itemcounts) 
 
$tableEntry = "<tr><td>$name</td><td>$svr</td>" 
$tableEntry +=  "<td>$topMailbox</td>" 
#Checking if mailbox count threshold is exceeded or not 
if ($topMailboxSize -gt $mbxSizeThreshold) 
{ 
 $topMailboxSize = $topMailboxSize/1mb ; $topMailboxSize =[Math]::Round($topMailboxSize,2) 
 $tableEntry += "<td bgcolor='#FF0000' align=center>$topMailboxSize</td>" 
} 
else 
{ 
 $topMailboxSize = $topMailboxSize/1mb ; $topMailboxSize =[Math]::Round($topMailboxSize,2) 
 $tableEntry += "<td align=center>$topMailboxSize</td>" 
} 

#Checking if item count is greater than configured threshold 
if ($CountItems -gt $itemcountcritical) 
{ 
 $tableEntry += "<td bgcolor='#FF0000' align=center>$itemcounts</td>" 
}
elseif ($CountItems -gt $itemcountwarning) 
{ 
 $tableEntry += "<td bgcolor='#FBB917' align=center>$itemcounts</td>" 
} 
else 
{ 
 $tableEntry += "<td align=center>$itemcounts</td>" 
} 
$tableentry += "<td>$edb</td>"
#Checking if EDB size is greater than the set  Threshold 
#If it is greater than the table cell will be marked red, else green. 
if ($edbSize -gt $dbSizeThreshold) 
{ 
 $edbSize = $edbSize/1mb 
 $tableEntry += "<td bgcolor='#FF0000' align=center>$edbSize</td>" 
} 
else 
{ 
 $edbSize = $edbSize/1mb 
 $tableEntry += "<td align=center>$edbSize</td>" 
}
 
#Checking if mailbox count is greater than configured threshold 
if ($mbxCount -gt $mailboxCountThreshold) 
{ 
 $tableEntry += "<td bgcolor='#FF0000' align=center>$mbxCount</td>" 
}
else 
{ 
 $tableEntry += "<td align=center>$mbxCount</td>" 
} 
$tableEntry +=  "<td>$whiteSpace</td>" 

#Checking how old is the backup 
 
 $tableEntry += "<td align=center>$lastbackup</td>" 
 $tableEntry += "<td align=center>$howOldBkp</td>" 


Add-Content $fileName $tableEntry 
Write-Host $tableEntry 
} 
 
Function sendEmail 
{ param($from,$to,$subject,$smtphost,$htmlFileName) 
$body = Get-Content $htmlFileName 
$smtp= New-Object System.Net.Mail.SmtpClient $smtphost 
$msg = New-Object System.Net.Mail.MailMessage $from, $to, $subject, $body 
$msg.isBodyhtml = $true 
$smtp.send($msg) 
} 
 
writehtmlheader $fileName 
writetableheader $fileName 
get-DBInfo 
writehtmlfooter $fileName 
 
sendEmail Administrator@contoso.com "donald.duck@contoso.com,mickey.mouse@contoso.com" "Contoso Exchange Journal Report" EXServer.Contoso.com $fileName 
